@@ -1,6 +1,14 @@
 #pragma once
 
-#include "catch.hpp"
+#if defined(__GNUC__) && __GNUC__ == 12
+#    pragma GCC diagnostic push
+#    pragma GCC diagnostic ignored "-Wmaybe-uninitialized" // Workaround for GCC 12
+#endif
+#include <catch2/catch_all.hpp>
+#if defined(__GNUC__) && __GNUC__ == 12
+#    pragma GCC diagnostic pop
+#endif
+
 #include "utils.h"
 #include <chrono>
 #include <cstdio>
@@ -17,10 +25,12 @@
 
 #include "spdlog/spdlog.h"
 #include "spdlog/async.h"
+#include "spdlog/details/fmt_helper.h"
 #include "spdlog/sinks/basic_file_sink.h"
 #include "spdlog/sinks/daily_file_sink.h"
 #include "spdlog/sinks/null_sink.h"
 #include "spdlog/sinks/ostream_sink.h"
 #include "spdlog/sinks/rotating_file_sink.h"
 #include "spdlog/sinks/stdout_color_sinks.h"
-#include "spdlog/pattern_formatter.h"
\ No newline at end of file
+#include "spdlog/sinks/msvc_sink.h"
+#include "spdlog/pattern_formatter.h"
