@@ -21,30 +21,26 @@ protected:
         throw std::runtime_error("some error happened during flush");
     }
 };
+struct custom_ex
+{};
 
-TEST_CASE("default_error_handler", "[errors]]")
+#if !defined(SPDLOG_USE_STD_FORMAT) // std formt doesn't fully support tuntime strings
+TEST_CASE("default_error_handler", "[errors]")
 {
     prepare_logdir();
     spdlog::filename_t filename = SPDLOG_FILENAME_T(SIMPLE_LOG);
 
     auto logger = spdlog::create<spdlog::sinks::basic_file_sink_mt>("test-error", filename, true);
     logger->set_pattern("%v");
-#ifdef SPDLOG_USE_STD_FORMAT
-    logger->info("Test message {} {}", 1);
-#else
-    logger->info(fmt::runtime("Test message {} {}"), 1);
-#endif
+    logger->info(SPDLOG_FMT_RUNTIME("Test message {} {}"), 1);
     logger->info("Test message {}", 2);
     logger->flush();
-
     using spdlog::details::os::default_eol;
     REQUIRE(file_contents(SIMPLE_LOG) == spdlog::fmt_lib::format("Test message 2{}", default_eol));
     REQUIRE(count_lines(SIMPLE_LOG) == 1);
 }
 
-struct custom_ex
-{};
-TEST_CASE("custom_error_handler", "[errors]]")
+TEST_CASE("custom_error_handler", "[errors]")
 {
     prepare_logdir();
     spdlog::filename_t filename = SPDLOG_FILENAME_T(SIMPLE_LOG);
@@ -53,16 +49,13 @@ TEST_CASE("custom_error_handler", "[errors]]")
     logger->set_error_handler([=](const std::string &) { throw custom_ex(); });
     logger->info("Good message #1");
 
-#ifdef SPDLOG_USE_STD_FORMAT
-    REQUIRE_THROWS_AS(logger->info("Bad format msg {} {}", "xxx"), custom_ex);
-#else
-    REQUIRE_THROWS_AS(logger->info(fmt::runtime("Bad format msg {} {}"), "xxx"), custom_ex);
-#endif
+    REQUIRE_THROWS_AS(logger->info(SPDLOG_FMT_RUNTIME("Bad format msg {} {}"), "xxx"), custom_ex);
     logger->info("Good message #2");
     require_message_count(SIMPLE_LOG, 2);
 }
+#endif
 
-TEST_CASE("default_error_handler2", "[errors]]")
+TEST_CASE("default_error_handler2", "[errors]")
 {
     spdlog::drop_all();
     auto logger = spdlog::create<failing_sink>("failed_logger");
@@ -70,7 +63,7 @@ TEST_CASE("default_error_handler2", "[errors]]")
     REQUIRE_THROWS_AS(logger->info("Some message"), custom_ex);
 }
 
-TEST_CASE("flush_error_handler", "[errors]]")
+TEST_CASE("flush_error_handler", "[errors]")
 {
     spdlog::drop_all();
     auto logger = spdlog::create<failing_sink>("failed_logger");
@@ -78,7 +71,8 @@ TEST_CASE("flush_error_handler", "[errors]]")
     REQUIRE_THROWS_AS(logger->flush(), custom_ex);
 }
 
-TEST_CASE("async_error_handler", "[errors]]")
+#if !defined(SPDLOG_USE_STD_FORMAT)
+TEST_CASE("async_error_handler", "[errors]")
 {
     prepare_logdir();
     std::string err_msg("log failed with some msg");
@@ -96,11 +90,7 @@ TEST_CASE("async_error_handler", "[errors]]")
             ofs << err_msg;
         });
         logger->info("Good message #1");
-#ifdef SPDLOG_USE_STD_FORMAT
-        logger->info("Bad format msg {} {}", "xxx");
-#else
-        logger->info(fmt::runtime("Bad format msg {} {}"), "xxx");
-#endif
+        logger->info(SPDLOG_FMT_RUNTIME("Bad format msg {} {}"), "xxx");
         logger->info("Good message #2");
         spdlog::drop("logger"); // force logger to drain the queue and shutdown
     }
@@ -108,9 +98,10 @@ TEST_CASE("async_error_handler", "[errors]]")
     require_message_count(SIMPLE_ASYNC_LOG, 2);
     REQUIRE(file_contents("test_logs/custom_err.txt") == err_msg);
 }
+#endif
 
 // Make sure async error handler is executed
-TEST_CASE("async_error_handler2", "[errors]]")
+TEST_CASE("async_error_handler2", "[errors]")
 {
     prepare_logdir();
     std::string err_msg("This is async handler error message");
